import { useRef, useEffect } from 'react';
import Inputmask from 'inputmask';

const isServer = !(typeof window !== 'undefined' && window.document && window.document.createElement);
function flow(...funcs) {
    const { length  } = funcs;
    let index = length;
    while(index--){
        if (typeof funcs[index] !== 'function') {
            throw new TypeError('Expected a function');
        }
    }
    return (...args)=>{
        let i = 0;
        let result = length ? funcs[i].apply(this, args) : args[0];
        while(++i < length){
            result = funcs[i].call(this, result);
        }
        return result;
    };
}

function _define_property$2(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _object_spread$2(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _define_property$2(target, key, source[key]);
        });
    }
    return target;
}
const useInputMask = (props)=>{
    const { mask , register , options  } = props;
    const ref = useRef(null);
    if (isServer) return ref;
    useEffect(()=>{
        if (!isServer) {
            if (!ref.current) return;
            const maskInput = Inputmask(_object_spread$2({
                mask
            }, options));
            maskInput.mask(ref.current);
            if (register && ref.current) {
                register(ref.current);
            }
        }
    }, [
        mask,
        register,
        options
    ]);
    return ref;
};

function _define_property$1(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _object_spread$1(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _define_property$1(target, key, source[key]);
        });
    }
    return target;
}
function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);
    if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);
        if (enumerableOnly) {
            symbols = symbols.filter(function(sym) {
                return Object.getOwnPropertyDescriptor(object, sym).enumerable;
            });
        }
        keys.push.apply(keys, symbols);
    }
    return keys;
}
function _object_spread_props(target, source) {
    source = source != null ? source : {};
    if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
        ownKeys(Object(source)).forEach(function(key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
    }
    return target;
}
const withHookFormMask = (register, mask, options)=>{
    //
    let newRef;
    if (register) {
        const { ref  } = register;
        const maskInput = Inputmask(_object_spread$1({
            mask: mask || undefined
        }, options));
        newRef = flow((_ref)=>{
            if (_ref) maskInput.mask(_ref);
            return _ref;
        }, ref);
    }
    return _object_spread_props(_object_spread$1({}, register), {
        ref: newRef
    });
};

function _define_property(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _object_spread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _define_property(target, key, source[key]);
        });
    }
    return target;
}
const withMask = (mask, options)=>(input)=>{
        //
        if (isServer) return input;
        const maskInput = Inputmask(_object_spread({
            mask: mask || undefined
        }, options));
        if (input) {
            maskInput.mask(input);
        }
        return input;
    };

export { useInputMask as default, withHookFormMask, withMask };
//# sourceMappingURL=index.js.map
